==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/operation/RedactType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RedactType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RedactType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="sanitize" type="{http://schema.webpdf.de/1.0/operation}SanitizeType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RedactType", propOrder = {
    "sanitize"
})
public class RedactType
    extends BaseToolboxType
{

    protected SanitizeType sanitize;

    /**
     * Gets the value of the sanitize property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeType }
     *     
     */
    public SanitizeType getSanitize() {
        return sanitize;
    }

    /**
     * Sets the value of the sanitize property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeType }
     *     
     */
    public void setSanitize(SanitizeType value) {
        this.sanitize = value;
    }

    public boolean isSetSanitize() {
        return (this.sanitize!= null);
    }

}

==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/RedactType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RedactType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RedactType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="sanitize" type="{http://schema.webpdf.de/1.0/operation}SanitizeType" minOccurs="0"/&gt;
 *         &lt;element name="blacken" type="{http://schema.webpdf.de/1.0/operation}BlackenType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RedactType", propOrder = {
    "sanitize",
    "blacken"
})
public class RedactType
    extends BaseToolboxType
{

    protected SanitizeType sanitize;
    protected BlackenType blacken;

    /**
     * Gets the value of the sanitize property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeType }
     *     
     */
    public SanitizeType getSanitize() {
        return sanitize;
    }

    /**
     * Sets the value of the sanitize property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeType }
     *     
     */
    public void setSanitize(SanitizeType value) {
        this.sanitize = value;
    }

    public boolean isSetSanitize() {
        return (this.sanitize!= null);
    }

    /**
     * Gets the value of the blacken property.
     * 
     * @return
     *     possible object is
     *     {@link BlackenType }
     *     
     */
    public BlackenType getBlacken() {
        return blacken;
    }

    /**
     * Sets the value of the blacken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BlackenType }
     *     
     */
    public void setBlacken(BlackenType value) {
        this.blacken = value;
    }

    public boolean isSetBlacken() {
        return (this.blacken!= null);
    }

}
